@@ -4,28 +4,28 @@
 <context>
     <name>DownloadExtractThread</name>
     <message>
-        <location filename="../downloadextractthread.cpp" line="166"/>
+        <location filename="../downloadextractthread.cpp" line="167"/>
         <source>Error writing to storage</source>
         <translation>Fehler beim Schreiben auf den Speicher</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="188"/>
-        <location filename="../downloadextractthread.cpp" line="348"/>
+        <location filename="../downloadextractthread.cpp" line="193"/>
+        <location filename="../downloadextractthread.cpp" line="382"/>
         <source>Error extracting archive: %1</source>
         <translation>Fehler beim Entpacken des Archivs: %1</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="234"/>
+        <location filename="../downloadextractthread.cpp" line="258"/>
         <source>Error mounting FAT32 partition</source>
         <translation>Fehler beim Einbinden der FAT32-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="244"/>
+        <location filename="../downloadextractthread.cpp" line="278"/>
         <source>Operating system did not mount FAT32 partition</source>
         <translation>Das Betriebssystem band die FAT32-Partition nicht ein</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="267"/>
+        <location filename="../downloadextractthread.cpp" line="301"/>
         <source>Error changing to directory &apos;%1&apos;</source>
         <translation>Fehler beim Wechseln in den Ordner &quot;%1&quot;</translation>
     </message>
@@ -33,32 +33,32 @@
 <context>
     <name>DownloadThread</name>
     <message>
-        <location filename="../downloadthread.cpp" line="110"/>
+        <location filename="../downloadthread.cpp" line="114"/>
         <source>opening drive</source>
-        <translation type="unfinished"></translation>
+        <translation>Gerät wird geöffnet</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="143"/>
+        <location filename="../downloadthread.cpp" line="147"/>
         <source>Error running diskpart: %1</source>
         <translation>Fehler beim Ausführen von Diskpart: %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="164"/>
+        <location filename="../downloadthread.cpp" line="168"/>
         <source>Error removing existing partitions</source>
         <translation>Fehler beim Entfernen von existierenden Partitionen</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="190"/>
+        <location filename="../downloadthread.cpp" line="194"/>
         <source>Authentication cancelled</source>
         <translation>Authentifizierung abgebrochen</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="193"/>
+        <location filename="../downloadthread.cpp" line="197"/>
         <source>Error running authopen to gain access to disk device &apos;%1&apos;</source>
         <translation>Fehler beim Ausführen von authopen, um Zugriff auf Geräte zu erhalten &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="194"/>
+        <location filename="../downloadthread.cpp" line="198"/>
         <source>Please verify if &apos;Raspberry Pi Imager&apos; is allowed access to &apos;removable volumes&apos; in privacy settings (under &apos;files and folders&apos; or alternatively give it &apos;full disk access&apos;).</source>
         <translatorcomment>I don&apos;t use Mac OS, I would need help here. Unfinished translation:
 
@@ -66,85 +66,135 @@ Bitte stellen Sie sicher, dass &apos;Raspberry Pi Imager&apos; Zugriff auf &apos
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="215"/>
+        <location filename="../downloadthread.cpp" line="219"/>
         <source>Cannot open storage device &apos;%1&apos;.</source>
         <translation>Speichergerät &apos;%1&apos; kann nicht geöffnet werden.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="257"/>
+        <location filename="../downloadthread.cpp" line="261"/>
         <source>discarding existing data on drive</source>
-        <translation type="unfinished"></translation>
+        <translation>Vorhandene Daten auf dem Medium werden gelöscht</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="277"/>
+        <location filename="../downloadthread.cpp" line="281"/>
         <source>zeroing out first and last MB of drive</source>
-        <translation type="unfinished"></translation>
+        <translation>Erstes und letztes Megabyte des Mediums werden überschrieben</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="283"/>
+        <location filename="../downloadthread.cpp" line="287"/>
         <source>Write error while zero&apos;ing out MBR</source>
         <translation>Schreibfehler während dem Löschen des MBR</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="295"/>
+        <location filename="../downloadthread.cpp" line="299"/>
         <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
         <translation>Fehler beim Löschen des letzten Teiles der Speicherkarte.&lt;br&gt;Die Speicherkarte könnte mit einer falschen Größe beworben sein (möglicherweise Betrug).</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="353"/>
+        <location filename="../downloadthread.cpp" line="388"/>
         <source>starting download</source>
+        <translation>Download wird gestartet</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="777"/>
+        <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
+        <translation>Fehler beim Lesen vom Speicher.&lt;br&gt;Die SD-Karte könnte defekt sein.</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="853"/>
+        <source>Waiting for FAT partition to be mounted</source>
+        <translation>Warten auf das Mounten der FAT-Partition</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="939"/>
+        <source>Error mounting FAT32 partition</source>
+        <translation>Fehler beim Einbinden der FAT32-Partition</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="961"/>
+        <source>Operating system did not mount FAT32 partition</source>
+        <translation>Das Betriebssystem band die FAT32-Partition nicht ein</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="994"/>
+        <source>Unable to customize. File &apos;%1&apos; does not exist.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="741"/>
-        <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
-        <translation>Fehler beim Lesen vom Speicher.&lt;br&gt;Die SD-Karte könnte kaputt sein.</translation>
+        <location filename="../downloadthread.cpp" line="998"/>
+        <source>Customizing image</source>
+        <translation>Image modifizieren</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="395"/>
+        <location filename="../downloadthread.cpp" line="1083"/>
+        <source>Error creating firstrun.sh on FAT partition</source>
+        <translation>Fehler beim Erstellen von firstrun.sh auf der FAT-Partition</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1035"/>
+        <source>Error writing to config.txt on FAT partition</source>
+        <translation>Fehler beim Schreiben in config.txt auf der FAT-Partition</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1100"/>
+        <source>Error creating user-data cloudinit file on FAT partition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1114"/>
+        <source>Error creating network-config cloudinit file on FAT partition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1137"/>
+        <source>Error writing to cmdline.txt on FAT partition</source>
+        <translation>Fehler beim Schreiben in cmdline.txt auf der FAT-Partition</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="431"/>
         <source>Access denied error while writing file to disk.</source>
         <translation>Zugriff verweigert-Fehler beim Schreiben auf den Datenträger.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="400"/>
+        <location filename="../downloadthread.cpp" line="436"/>
         <source>Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.</source>
         <translatorcomment>I don&apos;t use Windows either. What is &quot;Controlled Folder Access&quot; in the German version?
 
-Controlled Folder Access sheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-imager.exe als auch fat32format.exe zur Liste der erlaubten Apps hinzu und versuchen sie es erneut.</translatorcomment>
+Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-imager.exe als auch fat32format.exe zur Liste der erlaubten Apps hinzu und versuchen sie es erneut.</translatorcomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="406"/>
+        <location filename="../downloadthread.cpp" line="442"/>
         <source>Error writing file to disk</source>
         <translation>Fehler beim Schreiben der Datei auf den Speicher</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="425"/>
+        <location filename="../downloadthread.cpp" line="461"/>
         <source>Error downloading: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim Herunterladen: %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="632"/>
+        <location filename="../downloadthread.cpp" line="672"/>
         <source>Download corrupt. Hash does not match</source>
         <translation>Download beschädigt. Prüfsumme stimmt nicht überein</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="644"/>
+        <location filename="../downloadthread.cpp" line="684"/>
         <source>Error writing to storage (while flushing)</source>
         <translation>Fehler beim Schreiben auf den Speicher (während flushing)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="651"/>
+        <location filename="../downloadthread.cpp" line="691"/>
         <source>Error writing to storage (while fsync)</source>
         <translation>Fehler beim Schreiben auf den Speicher (während fsync)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="685"/>
+        <location filename="../downloadthread.cpp" line="717"/>
         <source>Error writing first block (partition table)</source>
         <translation>Fehler beim Schreiben auf des ersten Blocks (Partitionstabelle)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="760"/>
+        <location filename="../downloadthread.cpp" line="796"/>
         <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
         <translation>Verifizierung fehlgeschlagen. Der Inhalt der SD-Karte weicht von dem Inhalt ab, der geschrieben werden sollte.</translation>
     </message>
@@ -189,50 +239,60 @@ Controlled Folder Access sheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-i
         <translation>Fehler beim Starten von sfdisk</translation>
     </message>
     <message>
-        <location filename="../driveformatthread.cpp" line="196"/>
+        <location filename="../driveformatthread.cpp" line="199"/>
+        <source>Partitioning did not create expected FAT partition %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../driveformatthread.cpp" line="208"/>
         <source>Error starting mkfs.fat</source>
         <translation>Fehler beim Starten von mkfs.fat</translation>
     </message>
     <message>
-        <location filename="../driveformatthread.cpp" line="206"/>
+        <location filename="../driveformatthread.cpp" line="218"/>
         <source>Error running mkfs.fat: %1</source>
         <translation>Fehler beim Verwenden von mkfs.fat: %1</translation>
     </message>
     <message>
-        <location filename="../driveformatthread.cpp" line="213"/>
+        <location filename="../driveformatthread.cpp" line="225"/>
         <source>Formatting not implemented for this platform</source>
-        <translation>Formatieren ist auf dieser Platform nicht implementiert</translation>
+        <translation>Formatieren wird auf dieser Platform nicht unterstützt</translation>
     </message>
 </context>
 <context>
     <name>ImageWriter</name>
     <message>
-        <location filename="../imagewriter.cpp" line="171"/>
+        <location filename="../imagewriter.cpp" line="256"/>
         <source>Storage capacity is not large enough.&lt;br&gt;Needs to be at least %1 GB.</source>
         <translation>Die Speicherkapazität ist nicht groß genug.&lt;br&gt;Sie muss mindestens %1 GB betragen.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="177"/>
+        <location filename="../imagewriter.cpp" line="262"/>
         <source>Input file is not a valid disk image.&lt;br&gt;File size %1 bytes is not a multiple of 512 bytes.</source>
         <translation>Die Eingabedatei ist kein gültiges Disk-Image.&lt;br&gt;Die Dateigröße%1 Bytes ist kein Vielfaches von 512 Bytes.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="201"/>
+        <location filename="../imagewriter.cpp" line="444"/>
         <source>Downloading and writing image</source>
         <translation>Image herunterladen und schreiben</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="424"/>
+        <location filename="../imagewriter.cpp" line="577"/>
         <source>Select image</source>
         <translation>Image wählen</translation>
     </message>
+    <message>
+        <location filename="../imagewriter.cpp" line="975"/>
+        <source>Would you like to prefill the wifi password from the system keychain?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocalFileExtractThread</name>
     <message>
         <location filename="../localfileextractthread.cpp" line="34"/>
         <source>opening image file</source>
-        <translation type="unfinished"></translation>
+        <translation>Abbilddatei wird geöffnet</translation>
     </message>
     <message>
         <location filename="../localfileextractthread.cpp" line="39"/>
@@ -243,20 +303,168 @@ Controlled Folder Access sheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-i
 <context>
     <name>MsgPopup</name>
     <message>
-        <location filename="../MsgPopup.qml" line="96"/>
+        <location filename="../MsgPopup.qml" line="97"/>
         <source>NO</source>
         <translation>NEIN</translation>
     </message>
     <message>
-        <location filename="../MsgPopup.qml" line="109"/>
+        <location filename="../MsgPopup.qml" line="110"/>
         <source>YES</source>
         <translation>JA</translation>
     </message>
     <message>
-        <location filename="../MsgPopup.qml" line="122"/>
+        <location filename="../MsgPopup.qml" line="123"/>
         <source>CONTINUE</source>
         <translation>WEITER</translation>
     </message>
+    <message>
+        <location filename="../MsgPopup.qml" line="135"/>
+        <source>QUIT</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OptionsPopup</name>
+    <message>
+        <location filename="../OptionsPopup.qml" line="78"/>
+        <source>Advanced options</source>
+        <translation>Erweiterte Optionen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="95"/>
+        <source>Image customization options</source>
+        <translation>OS-Modifizierungen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="103"/>
+        <source>for this session only</source>
+        <translation>Nur für diese Sitzung</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="104"/>
+        <source>to always use</source>
+        <translation>Immer verwenden</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="117"/>
+        <source>Disable overscan</source>
+        <translation>Overscan deaktivieren</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="122"/>
+        <source>Set hostname:</source>
+        <translation>Hostname:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="141"/>
+        <source>Enable SSH</source>
+        <translation>SSH aktivieren</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="160"/>
+        <source>Use password authentication</source>
+        <translation>Password zur Authentifizierung verwenden</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="170"/>
+        <source>Allow public-key authentication only</source>
+        <translation>Authentifizierung via Public-Key</translation>
+    </message>
+    <message>
+        <source>Set password for &apos;%1&apos; user:</source>
+        <translation type="vanished">Passwort für &apos;%1&apos;:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="185"/>
+        <source>Set authorized_keys for &apos;%1&apos;:</source>
+        <translation>authorized_keys für &apos;%1&apos;:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="258"/>
+        <source>Configure wifi</source>
+        <translation>Wifi enrichten</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="277"/>
+        <source>SSID:</source>
+        <translation>SSID:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="231"/>
+        <location filename="../OptionsPopup.qml" line="297"/>
+        <source>Password:</source>
+        <translation>Passwort:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="197"/>
+        <source>Set username and password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="216"/>
+        <source>Username:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="292"/>
+        <source>Hidden SSID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="313"/>
+        <source>Show password</source>
+        <translation>Passwort anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="318"/>
+        <source>Wifi country:</source>
+        <translation>Wifi-Land:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="329"/>
+        <source>Set locale settings</source>
+        <translation>Spracheinstellungen festlegen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="339"/>
+        <source>Time zone:</source>
+        <translation>Zeitzone:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="349"/>
+        <source>Keyboard layout:</source>
+        <translation>Tastaturlayout:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="359"/>
+        <source>Skip first-run wizard</source>
+        <translation>Einrichtungsassistent überspringen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="366"/>
+        <source>Persistent settings</source>
+        <translation>Dauerhafte Einstellugen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="374"/>
+        <source>Play sound when finished</source>
+        <translation>Tonsignal nach Beenden abspielen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="378"/>
+        <source>Eject media when finished</source>
+        <translation>Medien nach Beenden auswerfen</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="382"/>
+        <source>Enable telemetry</source>
+        <translation>Telemetry aktivieren</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="395"/>
+        <source>SAVE</source>
+        <translation>SPEICHERN</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -266,6 +474,34 @@ Controlled Folder Access sheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-i
         <translation>Interner SD-Kartenleser</translation>
     </message>
 </context>
+<context>
+    <name>UseSavedSettingsPopup</name>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="71"/>
+        <source>Warning: advanced settings set</source>
+        <translation>Warnung: Erweiterte Optionen festgelegt</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="85"/>
+        <source>Would you like to apply the image customization settings saved earlier?</source>
+        <translation>Möchten Sie die vorher festgelegten OS-Modifizierungen anwenden?</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="94"/>
+        <source>NO, CLEAR SETTINGS</source>
+        <translation>NEIN, EINSTELLUNGEN LÖSCHEN</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="106"/>
+        <source>YES</source>
+        <translation>JA</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="118"/>
+        <source>EDIT SETTINGS</source>
+        <translation>EINSTELLUNGEN BEARBEITEN</translation>
+    </message>
+</context>
 <context>
     <name>main</name>
     <message>
@@ -274,224 +510,257 @@ Controlled Folder Access sheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-i
         <translation>Raspberry Pi Imager v%1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="90"/>
-        <location filename="../main.qml" line="303"/>
+        <location filename="../main.qml" line="98"/>
+        <location filename="../main.qml" line="422"/>
         <source>Operating System</source>
         <translation>Betriebssystem</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="102"/>
+        <location filename="../main.qml" line="110"/>
         <source>CHOOSE OS</source>
         <translation>OS WÄHLEN</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="120"/>
+        <location filename="../main.qml" line="125"/>
         <source>Select this button to change the operating system</source>
         <translation>Klicke auf diesen Knopf, um das Betriebssystem zu ändern</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="133"/>
-        <location filename="../main.qml" line="587"/>
-        <source>SD Card</source>
+        <location filename="../main.qml" line="138"/>
+        <location filename="../main.qml" line="718"/>
+        <source>Storage</source>
         <translation>SD-Karte</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="145"/>
-        <location filename="../main.qml" line="877"/>
-        <source>CHOOSE SD CARD</source>
+        <location filename="../main.qml" line="150"/>
+        <location filename="../main.qml" line="1038"/>
+        <source>CHOOSE STORAGE</source>
         <translation>SD-KARTE WÄHLEN</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="158"/>
         <source>Select this button to change the destination SD card</source>
-        <translation>Klicke auf diesen Knopf, um die Zeil-SD-Karte zu ändern</translation>
+        <translation type="vanished">Klicke auf diesen Knopf, um die Ziel-SD-Karte zu ändern</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="175"/>
+        <location filename="../main.qml" line="180"/>
         <source>WRITE</source>
         <translation>SCHREIBEN</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="180"/>
+        <location filename="../main.qml" line="185"/>
         <source>Select this button to start writing the image</source>
         <translation>Klicke auf diesen Knopf, um mit dem Schreiben zu beginnen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="220"/>
+        <location filename="../main.qml" line="230"/>
         <source>CANCEL WRITE</source>
         <translation>SCHREIBEN ABBRECHEN</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="815"/>
+        <location filename="../main.qml" line="233"/>
+        <location filename="../main.qml" line="968"/>
         <source>Cancelling...</source>
         <translation>Abbrechen...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="235"/>
+        <location filename="../main.qml" line="245"/>
         <source>CANCEL VERIFY</source>
         <translation>VERIFIZIERUNG ABBRECHEN</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="238"/>
-        <location filename="../main.qml" line="838"/>
-        <location filename="../main.qml" line="895"/>
+        <location filename="../main.qml" line="248"/>
+        <location filename="../main.qml" line="991"/>
+        <location filename="../main.qml" line="1057"/>
         <source>Finalizing...</source>
         <translation>Finalisieren...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="384"/>
-        <location filename="../main.qml" line="871"/>
+        <location filename="../main.qml" line="524"/>
+        <location filename="../main.qml" line="1025"/>
         <source>Erase</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="385"/>
+        <location filename="../main.qml" line="525"/>
         <source>Format card as FAT32</source>
         <translation>Karte als FAT32 formatieren</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="392"/>
+        <location filename="../main.qml" line="534"/>
         <source>Use custom</source>
         <translation>Eigenes Image</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="393"/>
+        <location filename="../main.qml" line="535"/>
         <source>Select a custom .img from your computer</source>
         <translation>Wählen Sie eine eigene .img-Datei von Ihrem Computer</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="482"/>
         <source>Back</source>
         <translation>Zurück</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="163"/>
+        <source>Select this button to change the destination storage device</source>
+        <translation>Klicken Sie auf diesen Knopf, um das Zeil-Speichermedium zu ändern</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="268"/>
+        <source>Select this button to access advanced settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="284"/>
+        <source>Using custom repository: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="293"/>
+        <source>Keyboard navigation: &lt;tab&gt; navigate to next button &lt;space&gt; press button/select item &lt;arrow up/down&gt; go up/down in lists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="313"/>
+        <source>Language: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="336"/>
+        <source>Keyboard: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="483"/>
         <source>Go back to main menu</source>
         <translation>Zurück zum Hauptmenü</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="474"/>
+        <location filename="../main.qml" line="600"/>
         <source>Released: %1</source>
         <translation>Veröffentlicht: %1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="477"/>
+        <location filename="../main.qml" line="603"/>
         <source>Cached on your computer</source>
         <translation>Auf Ihrem Computer zwischengespeichert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="479"/>
+        <location filename="../main.qml" line="605"/>
         <source>Local file</source>
         <translation>Lokale Datei</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="481"/>
+        <location filename="../main.qml" line="607"/>
         <source>Online - %1 GB download</source>
         <translation>Online - %1 GB Download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="638"/>
-        <location filename="../main.qml" line="690"/>
-        <location filename="../main.qml" line="696"/>
+        <location filename="../main.qml" line="769"/>
+        <location filename="../main.qml" line="821"/>
+        <location filename="../main.qml" line="827"/>
         <source>Mounted as %1</source>
         <translation>Als %1 eingebunden</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="692"/>
+        <location filename="../main.qml" line="823"/>
         <source>[WRITE PROTECTED]</source>
         <translation>[SCHREIBGESCHÜTZT]</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="734"/>
+        <location filename="../main.qml" line="865"/>
         <source>Are you sure you want to quit?</source>
         <translation>Sind Sie sicher, dass Sie beenden möchten?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="735"/>
+        <location filename="../main.qml" line="866"/>
         <source>Raspberry Pi Imager is still busy.&lt;br&gt;Are you sure you want to quit?</source>
         <translation>Der Raspberry Pi Imager ist noch beschäftigt. &lt;br&gt;Möchten Sie wirklich beenden?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="746"/>
+        <location filename="../main.qml" line="877"/>
         <source>Warning</source>
         <translation>Warnung</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="752"/>
+        <location filename="../main.qml" line="885"/>
         <source>Preparing to write...</source>
-        <translation type="unfinished"></translation>
+        <translation>Schreiben wird vorbereitet...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="776"/>
+        <location filename="../main.qml" line="909"/>
         <source>Update available</source>
-        <translation type="unfinished"></translation>
+        <translation>Update verfügbar</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="777"/>
+        <location filename="../main.qml" line="910"/>
         <source>There is a newer version of Imager available.&lt;br&gt;Would you like to visit the website to download it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Eine neuere Version von Imager ist verfügbar. &lt;br&gt;Möchten Sie die Webseite besuchen, um das Update herunterzuladen?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="818"/>
+        <location filename="../main.qml" line="971"/>
         <source>Writing... %1%</source>
         <translation>Schreiben... %1%</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="765"/>
+        <location filename="../main.qml" line="898"/>
         <source>All existing data on &apos;%1&apos; will be erased.&lt;br&gt;Are you sure you want to continue?</source>
-        <translation>Alle vorhandenen Daten auf &apos;%1&apos; werden gelöscht.&lt;br&gt;Möchten sie wirklich fortfahren?</translation>
+        <translation>Alle vorhandenen Daten auf &apos;%1&apos; werden gelöscht.&lt;br&gt;Möchten Sie wirklich fortfahren?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="797"/>
+        <location filename="../main.qml" line="950"/>
         <source>Error downloading OS list from Internet</source>
         <translation>Fehler beim Herunterladen der Betriebssystemsliste aus dem Internet</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="841"/>
+        <location filename="../main.qml" line="994"/>
         <source>Verifying... %1%</source>
         <translation>Verifizierung... %1%</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="848"/>
+        <location filename="../main.qml" line="1001"/>
         <source>Preparing to write... (%1)</source>
-        <translation type="unfinished"></translation>
+        <translation>Schreiben wird vorbereitet... (%1)</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="863"/>
+        <location filename="../main.qml" line="1017"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="870"/>
+        <location filename="../main.qml" line="1024"/>
         <source>Write Successful</source>
         <translation>Schreiben erfolgreich</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="872"/>
+        <location filename="../main.qml" line="1026"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been erased&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; wurde geleert&lt;br&gt;&lt;br&gt;Sie können die SD-Karte nun aus dem Lesegerät entfernen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="874"/>
+        <location filename="../main.qml" line="1028"/>
+        <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;</source>
+        <translation>&lt;b&gt;%1&lt;/b&gt; wurde auf&lt;b&gt;%2&lt;/b&gt; geschrieben</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1030"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; wurde auf&lt;b&gt;%2&lt;/b&gt; geschrieben&lt;br&gt;&lt;br&gt;Sie können die SD-Karte nun aus dem Lesegerät entfernen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="902"/>
-        <location filename="../main.qml" line="955"/>
+        <location filename="../main.qml" line="1096"/>
         <source>Error parsing os_list.json</source>
         <translation>Fehler beim Parsen von os_list.json</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="993"/>
+        <location filename="../main.qml" line="1250"/>
         <source>Connect an USB stick containing images first.&lt;br&gt;The images must be located in the root folder of the USB stick.</source>
         <translation>Verbinden Sie zuerst einen USB-Stick mit Images.&lt;br&gt;Die Images müssen sich im Wurzelverzeichnes des USB-Sticks befinden.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1008"/>
+        <location filename="../main.qml" line="1266"/>
         <source>SD card is write protected.&lt;br&gt;Push the lock switch on the left side of the card upwards, and try again.</source>
-        <translation>Die Speicherkarte ist schreibgeschützt.&lt;br&gt;Drücken Sie den Schutzschalter auf der linken Seite nach oben, und versuchen Sie es erneut.</translation>
+        <translation>Die Speicherkarte ist schreibgeschützt.&lt;br&gt;Schieben Sie den Schutzschalter auf der linken Seite nach oben, und versuchen Sie es erneut.</translation>
     </message>
 </context>
 </TS>
