@@ -1,31 +1,31 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="en_US">
+<TS version="2.1" language="it_IT">
 <context>
     <name>DownloadExtractThread</name>
     <message>
-        <location filename="../downloadextractthread.cpp" line="166"/>
+        <location filename="../downloadextractthread.cpp" line="167"/>
         <source>Error writing to storage</source>
         <translation>Errore scrittura nello storage</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="188"/>
-        <location filename="../downloadextractthread.cpp" line="348"/>
+        <location filename="../downloadextractthread.cpp" line="193"/>
+        <location filename="../downloadextractthread.cpp" line="382"/>
         <source>Error extracting archive: %1</source>
         <translation>Errore estrazione archivio: %1</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="234"/>
+        <location filename="../downloadextractthread.cpp" line="258"/>
         <source>Error mounting FAT32 partition</source>
         <translation>Errore montaggio partizione FAT32</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="244"/>
+        <location filename="../downloadextractthread.cpp" line="278"/>
         <source>Operating system did not mount FAT32 partition</source>
         <translation>Il sistema operativo non ha montato la partizione FAT32</translation>
     </message>
     <message>
-        <location filename="../downloadextractthread.cpp" line="267"/>
+        <location filename="../downloadextractthread.cpp" line="301"/>
         <source>Error changing to directory &apos;%1&apos;</source>
         <translation>Errore passaggio a cartella &apos;%1&apos;</translation>
     </message>
@@ -33,113 +33,163 @@
 <context>
     <name>DownloadThread</name>
     <message>
-        <location filename="../downloadthread.cpp" line="143"/>
+        <location filename="../downloadthread.cpp" line="147"/>
         <source>Error running diskpart: %1</source>
         <translation>Errore esecuzione diskpart: %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="164"/>
+        <location filename="../downloadthread.cpp" line="168"/>
         <source>Error removing existing partitions</source>
         <translation>Errore rimozione partizioni esistenti</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="190"/>
+        <location filename="../downloadthread.cpp" line="194"/>
         <source>Authentication cancelled</source>
         <translation>Autenticazione annullata</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="193"/>
+        <location filename="../downloadthread.cpp" line="197"/>
         <source>Error running authopen to gain access to disk device &apos;%1&apos;</source>
         <translation>Errore esecuzione auhopen per ottenere accesso al dispositivo disco %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="194"/>
+        <location filename="../downloadthread.cpp" line="198"/>
         <source>Please verify if &apos;Raspberry Pi Imager&apos; is allowed access to &apos;removable volumes&apos; in privacy settings (under &apos;files and folders&apos; or alternatively give it &apos;full disk access&apos;).</source>
         <translation>Verifica se a &apos;Raspberry Pi Imager&apos; è consentito l&apos;accesso a &apos;volumi rimovibili&apos; nelle impostazioni privacy (in &apos;file e cartelle&apos; o in alternativa concedi &apos;accesso completo al disco&apos;).</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="215"/>
+        <location filename="../downloadthread.cpp" line="219"/>
         <source>Cannot open storage device &apos;%1&apos;.</source>
         <translation>Impossibile aprire dispositivo storage &apos;%1&apos;.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="257"/>
+        <location filename="../downloadthread.cpp" line="261"/>
         <source>discarding existing data on drive</source>
         <translation>elimina i dati esistenti nell&apos;unità</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="277"/>
+        <location filename="../downloadthread.cpp" line="281"/>
         <source>zeroing out first and last MB of drive</source>
         <translation>azzera il primo e l&apos;ultimo MB dell&apos;unità</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="283"/>
+        <location filename="../downloadthread.cpp" line="287"/>
         <source>Write error while zero&apos;ing out MBR</source>
         <translation>Errore scrittura durante azzeramento MBR</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="741"/>
+        <location filename="../downloadthread.cpp" line="777"/>
         <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
         <translation>Errore lettura dallo storage.&lt;br&gt;La scheda SD potrebbe essere danneggiata.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="395"/>
+        <location filename="../downloadthread.cpp" line="853"/>
+        <source>Waiting for FAT partition to be mounted</source>
+        <translation>Attesa montaggio partizione FAT</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="939"/>
+        <source>Error mounting FAT32 partition</source>
+        <translation>Errore montaggio partizione FAT32</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="961"/>
+        <source>Operating system did not mount FAT32 partition</source>
+        <translation>Il sistema operativo non ha montato la partizione FAT32</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="994"/>
+        <source>Unable to customize. File &apos;%1&apos; does not exist.</source>
+        <translation>Impossibile personalizzare. Il file &apos;%1&apos; non esiste.</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="998"/>
+        <source>Customizing image</source>
+        <translation>Personalizza immagine</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1083"/>
+        <source>Error creating firstrun.sh on FAT partition</source>
+        <translation>Errore creazione firstrun.sh nella partizione FAT</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1035"/>
+        <source>Error writing to config.txt on FAT partition</source>
+        <translation>Errore scrittura in config.txt nella partizione FAT</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1100"/>
+        <source>Error creating user-data cloudinit file on FAT partition</source>
+        <translation>Errore nel creare il file cloudinit dei dati utente nella partizione FAT</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1114"/>
+        <source>Error creating network-config cloudinit file on FAT partition</source>
+        <translation>Errore durante la creazione del file network-config cloudinit nella partizione FAT</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="1137"/>
+        <source>Error writing to cmdline.txt on FAT partition</source>
+        <translation>Errore scrittura in cmdline.txt nella partizione FAT</translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="431"/>
         <source>Access denied error while writing file to disk.</source>
         <translation>Errore accesso negato durante la scrittura del file su disco.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="400"/>
+        <location filename="../downloadthread.cpp" line="436"/>
         <source>Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.</source>
         <translation>Sembra sia abilitato l&apos;accesso controllato alle cartelle. 
 Aggiungi sia &apos;rpi-imager.exe&apos; che &apos;fat32format.exe&apos; all&apos;elenco delle app consentite e riprova.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="406"/>
+        <location filename="../downloadthread.cpp" line="442"/>
         <source>Error writing file to disk</source>
         <translation>Errore scrittura file su disco</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="425"/>
+        <location filename="../downloadthread.cpp" line="461"/>
         <source>Error downloading: %1</source>
         <translation>Errore download: %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="644"/>
+        <location filename="../downloadthread.cpp" line="684"/>
         <source>Error writing to storage (while flushing)</source>
-        <translation>Errore scrittura nello storage (durante fluhisng)</translation>
+        <translation>Errore scrittura nello storage (durante flushing)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="651"/>
+        <location filename="../downloadthread.cpp" line="691"/>
         <source>Error writing to storage (while fsync)</source>
         <translation>Errore scrittura nello storage (durante fsync)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="632"/>
+        <location filename="../downloadthread.cpp" line="672"/>
         <source>Download corrupt. Hash does not match</source>
-        <translation>Downlaod corrotto.&lt;br&gt;L&apos;hash non corrisponde</translation>
+        <translation>Download corrotto.&lt;br&gt;L&apos;hash non corrisponde</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="110"/>
+        <location filename="../downloadthread.cpp" line="114"/>
         <source>opening drive</source>
         <translation>apertura unità</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="295"/>
+        <location filename="../downloadthread.cpp" line="299"/>
         <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
         <translation>Errore di scrittura durante il tentativo di azzerare l&apos;ultima parte della scheda.&lt;br&gt;La scheda potrebbe riportare una capacità maggiore di quella reale (possibile contraffazione).</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="353"/>
+        <location filename="../downloadthread.cpp" line="388"/>
         <source>starting download</source>
         <translation>avvio download</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="685"/>
+        <location filename="../downloadthread.cpp" line="717"/>
         <source>Error writing first block (partition table)</source>
         <translation>Errore scrittura primo blocco (tabella partizione)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="760"/>
+        <location filename="../downloadthread.cpp" line="796"/>
         <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
         <translation>Verifica scrittura fallita.&lt;br&gt;Il contenuto della SD è differente da quello che vi è stato scritto.</translation>
     </message>
@@ -184,17 +234,22 @@ Aggiungi sia &apos;rpi-imager.exe&apos; che &apos;fat32format.exe&apos; all&apos
         <translation>Errore avvio sfdisk</translation>
     </message>
     <message>
-        <location filename="../driveformatthread.cpp" line="196"/>
+        <location filename="../driveformatthread.cpp" line="199"/>
+        <source>Partitioning did not create expected FAT partition %1</source>
+        <translation>Il partizionamento non ha creato la partizione FAT prevista %1</translation>
+    </message>
+    <message>
+        <location filename="../driveformatthread.cpp" line="208"/>
         <source>Error starting mkfs.fat</source>
         <translation>Errore avvio mkfs.fat</translation>
     </message>
     <message>
-        <location filename="../driveformatthread.cpp" line="206"/>
+        <location filename="../driveformatthread.cpp" line="218"/>
         <source>Error running mkfs.fat: %1</source>
         <translation>Errore esecuzione mkfs.fat: %1</translation>
     </message>
     <message>
-        <location filename="../driveformatthread.cpp" line="213"/>
+        <location filename="../driveformatthread.cpp" line="225"/>
         <source>Formatting not implemented for this platform</source>
         <translation>Formattazione non implementata per questa piattaforma</translation>
     </message>
@@ -202,25 +257,30 @@ Aggiungi sia &apos;rpi-imager.exe&apos; che &apos;fat32format.exe&apos; all&apos
 <context>
     <name>ImageWriter</name>
     <message>
-        <location filename="../imagewriter.cpp" line="171"/>
+        <location filename="../imagewriter.cpp" line="256"/>
         <source>Storage capacity is not large enough.&lt;br&gt;Needs to be at least %1 GB.</source>
         <translation>La capacità dello storage non è sufficiente.&lt;br&gt;Sono necessari almeno %1 GB.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="177"/>
+        <location filename="../imagewriter.cpp" line="262"/>
         <source>Input file is not a valid disk image.&lt;br&gt;File size %1 bytes is not a multiple of 512 bytes.</source>
         <translation>Il file sorgente non è un&apos;immagine disco valida.&lt;br&gt;La dimensione file %1 non è un multiplo di 512 byte.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="201"/>
+        <location filename="../imagewriter.cpp" line="444"/>
         <source>Downloading and writing image</source>
         <translation>Download e scrittura file immagine</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="424"/>
+        <location filename="../imagewriter.cpp" line="577"/>
         <source>Select image</source>
         <translation>Seleziona file immagine</translation>
     </message>
+    <message>
+        <location filename="../imagewriter.cpp" line="975"/>
+        <source>Would you like to prefill the wifi password from the system keychain?</source>
+        <translation>Vuoi precompilare la password WiFi usando il portachiavi di sistema?</translation>
+    </message>
 </context>
 <context>
     <name>LocalFileExtractThread</name>
@@ -238,20 +298,172 @@ Aggiungi sia &apos;rpi-imager.exe&apos; che &apos;fat32format.exe&apos; all&apos
 <context>
     <name>MsgPopup</name>
     <message>
-        <location filename="../MsgPopup.qml" line="96"/>
+        <location filename="../MsgPopup.qml" line="97"/>
         <source>NO</source>
         <translation>NO</translation>
     </message>
     <message>
-        <location filename="../MsgPopup.qml" line="109"/>
+        <location filename="../MsgPopup.qml" line="110"/>
         <source>YES</source>
         <translation>SI</translation>
     </message>
     <message>
-        <location filename="../MsgPopup.qml" line="122"/>
+        <location filename="../MsgPopup.qml" line="123"/>
         <source>CONTINUE</source>
         <translation>CONTINUA</translation>
     </message>
+    <message>
+        <location filename="../MsgPopup.qml" line="135"/>
+        <source>QUIT</source>
+        <translation>ESCI</translation>
+    </message>
+</context>
+<context>
+    <name>OptionsPopup</name>
+    <message>
+        <location filename="../OptionsPopup.qml" line="78"/>
+        <source>Advanced options</source>
+        <translation>Opzioni avanzate</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="95"/>
+        <source>Image customization options</source>
+        <translation>Opzioni personalizzazione immagine</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="103"/>
+        <source>for this session only</source>
+        <translation>solo per questa sessione</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="104"/>
+        <source>to always use</source>
+        <translation>da usare sempre</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="117"/>
+        <source>Disable overscan</source>
+        <translation>Disabilita overscan</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="122"/>
+        <source>Set hostname:</source>
+        <translation>Imposta nome host:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="141"/>
+        <source>Enable SSH</source>
+        <translation>Abilita SSH</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="160"/>
+        <source>Use password authentication</source>
+        <translation>Usa password autenticazione</translation>
+    </message>
+    <message>
+        <source>Set password for &apos;pi&apos; user:</source>
+        <translation type="vanished">Imposta password utente &apos;pi&apos;:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="170"/>
+        <source>Allow public-key authentication only</source>
+        <translation>Permetti solo autenticazione con chiave pubblica</translation>
+    </message>
+    <message>
+        <source>Set authorized_keys for &apos;pi&apos;:</source>
+        <translation type="vanished">Imposta authorized_key per &apos;pi&apos;:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="185"/>
+        <source>Set authorized_keys for &apos;%1&apos;:</source>
+        <translation>Imposta authorized_keys per &apos;%1&apos;:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="258"/>
+        <source>Configure wifi</source>
+        <translation>Configura WiFi</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="277"/>
+        <source>SSID:</source>
+        <translation>SSID:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="231"/>
+        <location filename="../OptionsPopup.qml" line="297"/>
+        <source>Password:</source>
+        <translation>Password:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="197"/>
+        <source>Set username and password</source>
+        <translation>Imposta nome utente e password</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="216"/>
+        <source>Username:</source>
+        <translation>Nome utente:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="292"/>
+        <source>Hidden SSID</source>
+        <translation>SSID nascosto</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="313"/>
+        <source>Show password</source>
+        <translation>Visualizza password</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="318"/>
+        <source>Wifi country:</source>
+        <translation>Nazione WiFi:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="329"/>
+        <source>Set locale settings</source>
+        <translation>Imposta configurazioni locali</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="339"/>
+        <source>Time zone:</source>
+        <translation>Fuso orario:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="349"/>
+        <source>Keyboard layout:</source>
+        <translation>Layout tastiera:</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="359"/>
+        <source>Skip first-run wizard</source>
+        <translation>Salta procedura prima impostazione</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="366"/>
+        <source>Persistent settings</source>
+        <translation>Impostazioni persistenti</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="374"/>
+        <source>Play sound when finished</source>
+        <translation>Riproduci suono quando completato</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="378"/>
+        <source>Eject media when finished</source>
+        <translation>Espelli media quando completato</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="382"/>
+        <source>Enable telemetry</source>
+        <translation>Abilita telemetria</translation>
+    </message>
+    <message>
+        <location filename="../OptionsPopup.qml" line="395"/>
+        <source>SAVE</source>
+        <translation>SALVA</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -261,6 +473,34 @@ Aggiungi sia &apos;rpi-imager.exe&apos; che &apos;fat32format.exe&apos; all&apos
         <translation>Lettore scheda SD interno</translation>
     </message>
 </context>
+<context>
+    <name>UseSavedSettingsPopup</name>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="71"/>
+        <source>Warning: advanced settings set</source>
+        <translation>Attenzione: impostazioni avanzate impostate</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="85"/>
+        <source>Would you like to apply the image customization settings saved earlier?</source>
+        <translation>Vuoi applicare le impostazioni di personalizzazione dell&apos;immagine salvate in precedenza?</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="94"/>
+        <source>NO, CLEAR SETTINGS</source>
+        <translation>NO, AZZERA IMPOSTAZIONI</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="106"/>
+        <source>YES</source>
+        <translation>SI&apos;</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="118"/>
+        <source>EDIT SETTINGS</source>
+        <translation>MODIFICA IMPOSTAZIONI</translation>
+    </message>
+</context>
 <context>
     <name>main</name>
     <message>
@@ -269,222 +509,255 @@ Aggiungi sia &apos;rpi-imager.exe&apos; che &apos;fat32format.exe&apos; all&apos
         <translation>Raspberry Pi Imager v. %1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="90"/>
-        <location filename="../main.qml" line="303"/>
+        <location filename="../main.qml" line="98"/>
+        <location filename="../main.qml" line="422"/>
         <source>Operating System</source>
         <translation>Sistema operativo</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="102"/>
+        <location filename="../main.qml" line="110"/>
         <source>CHOOSE OS</source>
-        <translation>SCEGLI SO</translation>
+        <translation>SCEGLI S.O.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="120"/>
+        <location filename="../main.qml" line="125"/>
         <source>Select this button to change the operating system</source>
         <translation>Seleziona questo pulsante per modificare il sistema operativo scelto</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="133"/>
-        <location filename="../main.qml" line="587"/>
-        <source>SD Card</source>
+        <location filename="../main.qml" line="138"/>
+        <location filename="../main.qml" line="718"/>
+        <source>Storage</source>
         <translation>Scheda SD</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="145"/>
-        <location filename="../main.qml" line="877"/>
-        <source>CHOOSE SD CARD</source>
+        <location filename="../main.qml" line="150"/>
+        <location filename="../main.qml" line="1038"/>
+        <source>CHOOSE STORAGE</source>
         <translation>SCEGLI SCHEDA SD</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="158"/>
         <source>Select this button to change the destination SD card</source>
-        <translation>Seleziona questo pulsante per modificare la scheda SD destinazione</translation>
+        <translation type="vanished">Seleziona questo pulsante per modificare la scheda SD destinazione</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="175"/>
+        <location filename="../main.qml" line="180"/>
         <source>WRITE</source>
         <translation>SCRIVI</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="180"/>
+        <location filename="../main.qml" line="185"/>
         <source>Select this button to start writing the image</source>
         <translation>Seleziona questo pulsante per avviare la scrittura del file immagine</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="220"/>
+        <location filename="../main.qml" line="230"/>
         <source>CANCEL WRITE</source>
         <translation>ANNULLA SCRITTURA</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="815"/>
+        <location filename="../main.qml" line="233"/>
+        <location filename="../main.qml" line="968"/>
         <source>Cancelling...</source>
         <translation>Annullamento...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="235"/>
+        <location filename="../main.qml" line="245"/>
         <source>CANCEL VERIFY</source>
         <translation>ANNULLA VERIFICA</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="238"/>
-        <location filename="../main.qml" line="838"/>
-        <location filename="../main.qml" line="895"/>
+        <location filename="../main.qml" line="248"/>
+        <location filename="../main.qml" line="991"/>
+        <location filename="../main.qml" line="1057"/>
         <source>Finalizing...</source>
         <translation>Finalizzazione...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="384"/>
-        <location filename="../main.qml" line="871"/>
+        <location filename="../main.qml" line="524"/>
+        <location filename="../main.qml" line="1025"/>
         <source>Erase</source>
         <translation>Cancella</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="385"/>
+        <location filename="../main.qml" line="525"/>
         <source>Format card as FAT32</source>
         <translation>Formatta scheda come FAT32</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="392"/>
+        <location filename="../main.qml" line="534"/>
         <source>Use custom</source>
         <translation>Usa immagine personalizzata</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="393"/>
+        <location filename="../main.qml" line="535"/>
         <source>Select a custom .img from your computer</source>
         <translation>Seleziona un file immagine .img personalizzato</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="482"/>
         <source>Back</source>
         <translation>Indietro</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="163"/>
+        <source>Select this button to change the destination storage device</source>
+        <translation>Seleziona questo pulsante per modificare il dispositivo archiviazione destinazione</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="268"/>
+        <source>Select this button to access advanced settings</source>
+        <translation>Seleziona questo pulsante per accedere alle impostazioni avanzate</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="284"/>
+        <source>Using custom repository: %1</source>
+        <translation>Usa repository personalizzato: %1</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="293"/>
+        <source>Keyboard navigation: &lt;tab&gt; navigate to next button &lt;space&gt; press button/select item &lt;arrow up/down&gt; go up/down in lists</source>
+        <translation>Navigazione da tastiera: &lt;tab&gt; vai al prossimo pulsante &lt;spazio&gt; premi il pulsante/seleziona la voce &lt;freccia su/giù&gt; vai su/giù negli elenchi</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="313"/>
+        <source>Language: </source>
+        <translation>Lingua: </translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="336"/>
+        <source>Keyboard: </source>
+        <translation>Tastiera: </translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="483"/>
         <source>Go back to main menu</source>
         <translation>Torna al menu principale</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="474"/>
+        <location filename="../main.qml" line="600"/>
         <source>Released: %1</source>
         <translation>Rilasciato: %1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="477"/>
+        <location filename="../main.qml" line="603"/>
         <source>Cached on your computer</source>
-        <translation>Cachato nel computer</translation>
+        <translation>Memorizzato temporaneamente nel computer</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="479"/>
+        <location filename="../main.qml" line="605"/>
         <source>Local file</source>
         <translation>File locale</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="481"/>
+        <location filename="../main.qml" line="607"/>
         <source>Online - %1 GB download</source>
         <translation>Online - Download %1 GB</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="638"/>
-        <location filename="../main.qml" line="690"/>
-        <location filename="../main.qml" line="696"/>
+        <location filename="../main.qml" line="769"/>
+        <location filename="../main.qml" line="821"/>
+        <location filename="../main.qml" line="827"/>
         <source>Mounted as %1</source>
         <translation>Montato come %1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="692"/>
+        <location filename="../main.qml" line="823"/>
         <source>[WRITE PROTECTED]</source>
         <translation>[PROTETTA DA SCRITTURA]</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="734"/>
+        <location filename="../main.qml" line="865"/>
         <source>Are you sure you want to quit?</source>
         <translation>Sei sicuro di voler uscire?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="735"/>
+        <location filename="../main.qml" line="866"/>
         <source>Raspberry Pi Imager is still busy.&lt;br&gt;Are you sure you want to quit?</source>
         <translation>Raspberry Pi Image è occupato.&lt;br&gt;Sei sicuro di voler uscire?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="746"/>
+        <location filename="../main.qml" line="877"/>
         <source>Warning</source>
         <translation>Attenzione</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="752"/>
+        <location filename="../main.qml" line="885"/>
         <source>Preparing to write...</source>
         <translation>Preparazione scrittura...</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="776"/>
+        <location filename="../main.qml" line="909"/>
         <source>Update available</source>
         <translation>Aggiornamento disponibile</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="777"/>
+        <location filename="../main.qml" line="910"/>
         <source>There is a newer version of Imager available.&lt;br&gt;Would you like to visit the website to download it?</source>
         <translation>È disponibile una nuova versione di Imager.&lt;br&gt;Vuoi visitare il sito web per scaricare la nuova versione?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="818"/>
+        <location filename="../main.qml" line="971"/>
         <source>Writing... %1%</source>
         <translation>Scrittura...%1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="765"/>
+        <location filename="../main.qml" line="898"/>
         <source>All existing data on &apos;%1&apos; will be erased.&lt;br&gt;Are you sure you want to continue?</source>
         <translation>Tutti i dati esistenti in &apos;%1&apos; verranno eliminati.&lt;br&gt;Sei sicuro di voler continuare?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="797"/>
+        <location filename="../main.qml" line="950"/>
         <source>Error downloading OS list from Internet</source>
         <translation>Errore durante download elenco SO da internet</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="841"/>
+        <location filename="../main.qml" line="994"/>
         <source>Verifying... %1%</source>
         <translation>Verifica...%1</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="848"/>
+        <location filename="../main.qml" line="1001"/>
         <source>Preparing to write... (%1)</source>
         <translation>Preparazione scrittura... (%1)</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="863"/>
+        <location filename="../main.qml" line="1017"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="870"/>
+        <location filename="../main.qml" line="1024"/>
         <source>Write Successful</source>
         <translation>Scrittura completata senza errori</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="872"/>
+        <location filename="../main.qml" line="1026"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been erased&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>Azzeramento di &lt;b&gt;%1&lt;/b&gt; completato&lt;br&gt;&lt;br&gt;Ora puoi rimuovere la scheda SD dal lettore</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="874"/>
+        <location filename="../main.qml" line="1028"/>
+        <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;</source>
+        <translation>Scrittura di &lt;b&gt;%1&lt;/b&gt; in &lt;b&gt;%2&lt;/b&gt;completata</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="1030"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>Scrittura di &lt;b&gt;%1&lt;/b&gt; in &lt;b&gt;%2&lt;/b&gt;completata&lt;br&gt;&lt;br&gt;Ora puoi rimuovere la scheda SD dal lettore</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="902"/>
-        <location filename="../main.qml" line="955"/>
+        <location filename="../main.qml" line="1096"/>
         <source>Error parsing os_list.json</source>
         <translation>Errore durante analisi file os_list.json</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="993"/>
+        <location filename="../main.qml" line="1250"/>
         <source>Connect an USB stick containing images first.&lt;br&gt;The images must be located in the root folder of the USB stick.</source>
         <translation>Prima collega una chiavetta USB contenente il file immagine.&lt;br&gt;Il file immagine deve essere presente nella cartella principale della chiavetta USB.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1008"/>
+        <location filename="../main.qml" line="1266"/>
         <source>SD card is write protected.&lt;br&gt;Push the lock switch on the left side of the card upwards, and try again.</source>
         <translation>La scheda SD è protetta da scrittura.&lt;br&gt;Sposta verso l&apos;alto l&apos;interruttore LOCK sul lato sinistro della scheda SD e riprova.</translation>
     </message>
